package java.time.chrono;

import java.time.temporal.Temporal;
import java.util.Iterator;
import java.util.List;
import java.time.temporal.TemporalUnit;
import java.util.Objects;
import java.time.temporal.TemporalAmount;

public interface ChronoPeriod extends TemporalAmount
{
    public static ChronoPeriod between(ChronoLocalDate obj, ChronoLocalDate obj2) {
        Objects.requireNonNull(obj, "startDateInclusive");
        Objects.requireNonNull(obj2, "endDateExclusive");
        return obj.until(obj2);
    }
    
    public abstract long get(TemporalUnit p0);
    
    public abstract List<TemporalUnit> getUnits();
    
    public abstract Chronology getChronology();
    
    default public boolean isZero() {
        Iterator<TemporalUnit> iterator = this.getUnits().iterator();
        while (iterator.hasNext()) {
            if (this.get((TemporalUnit)iterator.next()) != 0L) {
                return false;
            }
            continue;
        }
        return true;
    }
    
    default public boolean isNegative() {
        Iterator<TemporalUnit> iterator = this.getUnits().iterator();
        while (iterator.hasNext()) {
            if (this.get((TemporalUnit)iterator.next()) < 0L) {
                return true;
            }
            continue;
        }
        return false;
    }
    
    public abstract ChronoPeriod plus(TemporalAmount p0);
    
    public abstract ChronoPeriod minus(TemporalAmount p0);
    
    public abstract ChronoPeriod multipliedBy(int p0);
    
    default public ChronoPeriod negated() {
        return this.multipliedBy(-1);
    }
    
    public abstract ChronoPeriod normalized();
    
    public abstract Temporal addTo(Temporal p0);
    
    public abstract Temporal subtractFrom(Temporal p0);
    
    public abstract boolean equals(Object p0);
    
    public abstract int hashCode();
    
    public abstract String toString();
}
